package core.api.controller;

import core.api.models.auth.SimpleStatusResponse;
import core.api.models.timemanager.taskgroup.TaskgroupEntityInfo;
import core.api.models.timemanager.taskgroup.TaskgroupFieldInfo;
import core.entities.timemanager.Taskgroup;
import core.services.ServiceExitCode;
import core.services.ServiceResult;
import core.services.TaskgroupService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.security.core.context.SecurityContextHolder;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;

@CrossOrigin(origins = "*", maxAge = 3600)
@RestController
@RequestMapping("/api/settings")
public class TaskgroupController {

    private final TaskgroupService taskgroupService;

    public TaskgroupController(@Autowired TaskgroupService taskgroupService) {
        this.taskgroupService = taskgroupService;
    }

    @PutMapping("/taskgroups")
    public ResponseEntity<?> createTaskgroup(@Valid @RequestBody TaskgroupFieldInfo fieldInfo) {
        String username = SecurityContextHolder.getContext().getAuthentication().getName();
        ServiceResult<Taskgroup> creationResult = taskgroupService.addTaskgroup(fieldInfo, username);
        if(creationResult.getExitCode() == ServiceExitCode.OK) {
            return ResponseEntity.ok(new TaskgroupEntityInfo(creationResult.getResult()));
        } else {
            return ResponseEntity.status(409).body(new SimpleStatusResponse("failed"));
        }
    }
}
