package core.services;

import core.api.models.timemanager.taskgroup.TaskgroupEntityInfo;
import core.api.models.timemanager.taskgroup.TaskgroupFieldInfo;
import core.entities.User;
import core.entities.UserRole;
import core.entities.timemanager.Taskgroup;
import core.repositories.UserRepository;
import core.repositories.timemanager.TaskgroupRepository;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.config.Task;
import org.springframework.stereotype.Service;

import java.util.NoSuchElementException;
import java.util.Optional;

@Service
public class TaskgroupService {

    private final TaskgroupRepository taskgroupRepository;
    private final UserRepository userRepository;
    public TaskgroupService(@Autowired  TaskgroupRepository taskgroupRepository,
                            @Autowired UserRepository userRepository) {
        this.taskgroupRepository = taskgroupRepository;
        this.userRepository = userRepository;
    }

    public ServiceResult<Taskgroup> addTaskgroup(TaskgroupFieldInfo taskData, String username) {
        Optional<User> user = userRepository.findByUsername(username);
        if(user.isEmpty()) {
            throw new NoSuchElementException();
        }

        if(!taskgroupRepository.existsByTaskgroupName(taskData.getName())) {

            Taskgroup taskgroup = new Taskgroup(taskData.getName(), user.get());
            taskgroupRepository.save(taskgroup);
            return new ServiceResult<>(taskgroup);
        } else {
            return new ServiceResult<>(ServiceExitCode.ENTITY_ALREADY_EXIST);
        }
    }
}
